/// <reference types="node" />
import React from 'react';
import PropTypes from 'prop-types';
import { BodyModeListener, CustomColor } from './types';
import { Effect, Offset, Place, TooltipProps, Wrapper } from './TooltipProps';
declare type TooltipState = {
    uuid: string;
    place: Place;
    desiredPlace: Place;
    type: string;
    effect: Effect;
    show: boolean;
    border: boolean;
    customColors: CustomColor;
    offset: Offset;
    padding: string;
    extraClass: string;
    html: boolean;
    delayHide: number;
    delayUpdate: number;
    delayShow: number;
    event: string;
    eventOff: string;
    currentEvent?: React.MouseEvent<HTMLElement>;
    currentTarget: HTMLElement | null;
    ariaProps: any;
    isEmptyTip: boolean;
    disable: boolean;
    possibleCustomEvents: string;
    possibleCustomEventsOff: string;
    originTooltip?: string;
    isMultiline: boolean;
};
declare type GetContentFn = {
    (data: string): any;
};
export declare type GetContentTypes = GetContentFn | string;
declare class ReactTooltip extends React.Component<TooltipProps, TooltipState> {
    mount: boolean;
    delayShowLoop?: NodeJS.Timeout;
    delayHideLoop?: NodeJS.Timeout;
    delayReshow?: NodeJS.Timeout;
    intervalUpdateContent?: NodeJS.Timer;
    tooltipRef?: HTMLElement;
    removalTracker?: MutationObserver;
    bodyModeListeners: BodyModeListener;
    static get propTypes(): {
        uuid: PropTypes.Requireable<string>;
        children: PropTypes.Requireable<any>;
        place: PropTypes.Requireable<string>;
        type: PropTypes.Requireable<string>;
        effect: PropTypes.Requireable<string>;
        offset: PropTypes.Requireable<object>;
        padding: PropTypes.Requireable<string>;
        multiline: PropTypes.Requireable<boolean>;
        border: PropTypes.Requireable<boolean>;
        textColor: PropTypes.Requireable<string>;
        backgroundColor: PropTypes.Requireable<string>;
        borderColor: PropTypes.Requireable<string>;
        arrowColor: PropTypes.Requireable<string>;
        insecure: PropTypes.Requireable<boolean>;
        class: PropTypes.Requireable<string>;
        className: PropTypes.Requireable<string>;
        id: PropTypes.Requireable<string>;
        html: PropTypes.Requireable<boolean>;
        delayHide: PropTypes.Requireable<number>;
        delayUpdate: PropTypes.Requireable<number>;
        delayShow: PropTypes.Requireable<number>;
        event: PropTypes.Requireable<string>;
        eventOff: PropTypes.Requireable<string>;
        isCapture: PropTypes.Requireable<boolean>;
        globalEventOff: PropTypes.Requireable<string>;
        getContent: PropTypes.Requireable<any>;
        afterShow: PropTypes.Requireable<(...args: any[]) => any>;
        afterHide: PropTypes.Requireable<(...args: any[]) => any>;
        overridePosition: PropTypes.Requireable<(...args: any[]) => any>;
        disable: PropTypes.Requireable<boolean>;
        scrollHide: PropTypes.Requireable<boolean>;
        resizeHide: PropTypes.Requireable<boolean>;
        wrapper: PropTypes.Requireable<string>;
        bodyMode: PropTypes.Requireable<boolean>;
        possibleCustomEvents: PropTypes.Requireable<string>;
        possibleCustomEventsOff: PropTypes.Requireable<string>;
        clickable: PropTypes.Requireable<boolean>;
    };
    static defaultProps: {
        insecure: boolean;
        resizeHide: boolean;
        wrapper: Wrapper;
        clickable: boolean;
    };
    static supportedWrappers: string[];
    static displayName: string;
    constructor(props: TooltipProps);
    /**
     * For unify the bind and unbind listener
     */
    bind(methodArray: any[]): void;
    bindRemovalTracker(): void;
    unbindRemovalTracker(): void;
    isCapture(currentTarget: HTMLElement): boolean;
    isBodyMode(): boolean;
    bindBodyListener(targetArray: any[]): void;
    unbindBodyListener(body?: HTMLBodyElement): void;
    getEffect(currentTarget: HTMLElement): Effect;
    componentDidMount(): void;
    static getDerivedStateFromProps(nextProps: any, prevState: any): any;
    isCustomEvent(ele: HTMLElement): string | boolean;
    customBindListener(ele: HTMLElement): void;
    customUnbindListener(ele: HTMLElement): void;
    componentWillUnmount(): void;
    static hide(): void;
    static rebuild(): void;
    static show(): void;
    globalRebuild(): void;
    globalShow(event: any): void;
    globalHide(event: any): void;
    bindWindowEvents(resizeHide: any): void;
    unbindWindowEvents(): void;
    onWindowResize(): void;
    injectStyles(): void;
    /**
     * Return if the mouse is on the tooltip.
     * @returns {boolean} true - mouse is on the tooltip
     */
    mouseOnToolTip(): boolean;
    /**
     * Pick out corresponded target elements
     */
    getTargetArray(id: string): any[];
    /**
     * Bind listener to the target elements
     * These listeners used to trigger showing or hiding the tooltip
     */
    bindListener(): void;
    /**
     * Unbind listeners on target elements
     */
    unbindListener(): void;
    /**
     * Invoke this before bind listener and unmount the component
     * it is necessary to invoke this even when binding custom event
     * so that the tooltip can switch between custom and default listener
     */
    unbindBasicListener(target: any): void;
    getTooltipContent(): any;
    isEmptyTip(placeholder: any): boolean;
    /**
     * When mouse enter, show the tooltip
     */
    showTooltip(e: React.MouseEvent<HTMLElement>, isGlobalCall: any): void;
    /**
     * When mouse hover, update tool tip
     */
    updateTooltip(e: React.MouseEvent<HTMLElement>): void;
    listenForTooltipExit(): void;
    removeListenerForTooltipExit(): void;
    /**
     * When mouse leave, hide tooltip
     */
    hideTooltip(e?: any, hasTarget?: any, options?: {
        isScroll: boolean;
    }): void;
    /**
     * When scroll, hide tooltip
     */
    hideTooltipOnScroll: (event: Event) => void;
    /**
     * Add scroll event listener when tooltip show
     * automatically hide the tooltip when scrolling
     */
    addScrollListener(currentTarget: any): void;
    removeScrollListener(currentTarget: any): void;
    updatePosition(callbackAfter?: any): void;
    /**
     * CLear all kinds of timeout of interval
     */
    clearTimer(): void;
    hasCustomColors(): boolean;
    render(): JSX.Element;
}
export default ReactTooltip;
//# sourceMappingURL=ReactTooltip.d.ts.map